export { default as groupBy } from 'lodash/groupBy.js';
export { default as deepMerge } from 'deepmerge';
/**
 * Sort object by alphabetizing keys.
 */
export declare function sortObject<T extends Record<string, unknown>>(theObject: T): T;
/**
 * Remove empty objects in nested object.
 * Leverage stringify to convert empty objects to undefined, which is removed
 * during stringification.
 */
export declare const removeEmptyObjects: <T extends Record<string, unknown>>(src: T) => Partial<T>;
/**
 * Removes keys like `{ x: undefined }` from the object
 */
export declare function removeUndefinedProps<T extends Record<PropertyKey, unknown>>(obj: T): T;
/**
 * Sort object and arrays recursively by alphabetizing keys.
 */
export declare function sortKeysRecursive(object: any): any;
/**
 * Turn a nested object into a single-level object with dot notation keys and
 * values equal to the deepest **object** in the nested object.
 */
export declare function flatten(obj: Record<string, unknown>): Record<string, Record<string, unknown>>;
/**
 * This function takes a dictionary of objects and returns an array of objects with the `id` merged into the object.
 * Helpful when you have a dictionary of objects and you want to add the `id` to the object (from dictionary key) then want to use array methods.
 * Example:
 * ```ts
 * const dictionary = {
 *  '123': { name: 'foo' },
 *  '456': { name: 'bar' },
 * }
 *
 * dictionaryToArray(dictionary).forEach(({ id, name }) => {
 *   // stuff
 * })
 * ```
 * @see {@link updateDictionaryWithId}
 */
export declare function dictionaryToArray<T extends Record<string, any>>(dictionary: Record<string, T>): (T & {
    id: string;
})[];
/**
 * This function takes a dictionary of objects and returns a dictionary of objects with the `id` merged into the object.
 * Helpful when you have a dictionary of objects and you want to add the `id` to the object (from dictionary key)
 * @see {@link dictionaryToArray}
 * @example
 * ```ts
 * const dictionary = {
 * '123': { name: 'foo' },
 * '456': { name: 'bar' },
 * }
 *
 * const dictionaryWithId = updateDictionaryWithId(dictionary)
 * // Which is now:
 * {
 *   '123': { id: '123', name: 'foo' },
 *   '456': { id: '456', name: 'bar' },
 * }
 * ```
 */
export declare function updateDictionaryWithId<T extends Record<string, any>>(dict: Record<string, T>): Record<string, T & {
    id: string;
}>;
//# sourceMappingURL=objects.d.ts.map